==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-scatterChart.dart <==
/*

Imports:

charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-scatterChart.dart';
import 'package:charts_flutter/flutter.dart' as charts;

Usage:


- Defining the callback and Scatter Chart objects

 List<ScatterChartClass> lBlockchain = [new ScatterChartClass("Blockchain", 52, 0.75, 14.0,Colors.grey),];
    List<ScatterChartClass> lCloud = [new ScatterChartClass("Cloud", 45, 0.6, 18.0, Colors.orange),];
    List<ScatterChartClass> lFlutter = [new ScatterChartClass("Flutter",60, 0.78, 17.0, Colors.blue)];
    List<ScatterChartClass> lMulesoft = [new ScatterChartClass("Mulesoft",25, 0.6, 13.0,  Colors.black),];
    List<ScatterChartClass> lSalesforce = [new ScatterChartClass("Salesforce",34, 0.5, 15.0, Colors.red),];

    List<charts.Series<ScatterChartClass, int>> seriesList = [
      new charts.Series<ScatterChartClass, int>(
          id:  lBlockchain[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lBlockchain),
      new charts.Series<ScatterChartClass, int>(
          id: lCloud[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lCloud),
      new charts.Series<ScatterChartClass, int>(
          id: lFlutter[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lFlutter),
      new charts.Series<ScatterChartClass, int>(
          id: lMulesoft[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lMulesoft),
      new charts.Series<ScatterChartClass, int>(
          id: lSalesforce[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage ,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lSalesforce),
    ];

    ChartsScatter objScatterChart = new ChartsScatter(seriesList);




- Object call for the widget


  body:objScatterChart






*/

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'consts.dart' as con;

class ChartsScatter extends StatefulWidget{
  List<charts.Series<dynamic,dynamic>> chartData;

  ChartsScatter(this.chartData);

  @override
  State<StatefulWidget> createState() {
    return _chartsscatter(chartData);
  }
}

class _chartsscatter extends State<ChartsScatter>{
  List<charts.Series<dynamic,dynamic>> chartData;

  _chartsscatter(this.chartData);

  @override
  Widget build(BuildContext context) {
    return _CreateScatterChart(chartData);
  }

  Widget _CreateScatterChart(List<charts.Series<dynamic,dynamic>> objSeries)
  {
    charts.ScatterPlotChart mScatterChart;
    mScatterChart = new charts.ScatterPlotChart(objSeries,
      // Set up a bucketing axis that will place all values below 0.1 (10%)
      // into a bucket at the bottom of the chart.
      //
      // Configure a tick count of 3 so that we get 100%, 50%, and the
      // threshold.
      primaryMeasureAxis: new charts.BucketingAxisSpec(
          threshold: 0.1,
          tickProviderSpec: new charts.BucketingNumericTickProviderSpec(
              desiredTickCount: 3)),
      // Add a series legend to display the series names.
      behaviors: [
        new charts.SeriesLegend(position: charts.BehaviorPosition.end),
      ],
      animate: true,
      animationDuration: Duration(seconds: con.five),
    );
    return mScatterChart;

  }


}

==> flutter_catalogue_widgets-0.0.7.tar.gz: lib/custom-scatterChart.dart <==
/*

Imports:

charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-scatterChart.dart';
import 'package:charts_flutter/flutter.dart' as charts;

Usage:


- Defining the callback and Scatter Chart objects

 List<ScatterChartClass> lBlockchain = [new ScatterChartClass("Blockchain", 52, 0.75, 14.0,Colors.grey),];
    List<ScatterChartClass> lCloud = [new ScatterChartClass("Cloud", 45, 0.6, 18.0, Colors.orange),];
    List<ScatterChartClass> lFlutter = [new ScatterChartClass("Flutter",60, 0.78, 17.0, Colors.blue)];
    List<ScatterChartClass> lMulesoft = [new ScatterChartClass("Mulesoft",25, 0.6, 13.0,  Colors.black),];
    List<ScatterChartClass> lSalesforce = [new ScatterChartClass("Salesforce",34, 0.5, 15.0, Colors.red),];

    List<charts.Series<ScatterChartClass, int>> seriesList = [
      new charts.Series<ScatterChartClass, int>(
          id:  lBlockchain[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lBlockchain),
      new charts.Series<ScatterChartClass, int>(
          id: lCloud[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lCloud),
      new charts.Series<ScatterChartClass, int>(
          id: lFlutter[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lFlutter),
      new charts.Series<ScatterChartClass, int>(
          id: lMulesoft[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lMulesoft),
      new charts.Series<ScatterChartClass, int>(
          id: lSalesforce[0].datalabel,
          colorFn: (ScatterChartClass sales, _) =>
              charts.ColorUtil.fromDartColor(sales.color),
          domainFn: (ScatterChartClass sales, _) => sales.xValue,
          measureFn: (ScatterChartClass sales, _) => sales.yPercentage ,
          radiusPxFn: (ScatterChartClass sales, _) => sales.radius,
          data: lSalesforce),
    ];

    ChartsScatter objScatterChart = new ChartsScatter(seriesList);




- Object call for the widget


  body:objScatterChart






*/

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'consts.dart' as con;

class ChartsScatter extends StatefulWidget{
  List<charts.Series<dynamic,dynamic>> chartData;

  ChartsScatter(this.chartData);

  @override
  State<StatefulWidget> createState() {
    return _Chartsscatter(chartData);
  }
}

class _Chartsscatter extends State<ChartsScatter>{
  List<charts.Series<dynamic,dynamic>> chartData;

  _Chartsscatter(this.chartData);

  @override
  Widget build(BuildContext context) {
    return _createScatterChart(chartData);
  }

  Widget _createScatterChart(List<charts.Series<dynamic,dynamic>> objSeries)
  {
    charts.ScatterPlotChart mScatterChart;
    mScatterChart = new charts.ScatterPlotChart(objSeries,
      // Set up a bucketing axis that will place all values below 0.1 (10%)
      // into a bucket at the bottom of the chart.
      //
      // Configure a tick count of 3 so that we get 100%, 50%, and the
      // threshold.
      primaryMeasureAxis: new charts.BucketingAxisSpec(
          threshold: 0.1,
          tickProviderSpec: new charts.BucketingNumericTickProviderSpec(
              desiredTickCount: 3)),
      // Add a series legend to display the series names.
      behaviors: [
        new charts.SeriesLegend(position: charts.BehaviorPosition.end),
      ],
      animate: true,
      animationDuration: Duration(seconds: con.five),
    );
    return mScatterChart;

  }


}
